package com.springboot.sseemitter.controller;

import com.springboot.sseemitter.model.Emp;
import com.springboot.sseemitter.model.service.EmpServ;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.servlet.mvc.method.annotation.SseEmitter;

import java.io.IOException;
import java.util.List;
import java.util.concurrent.ExecutorService;

//Causes Lombok to generate a logger field.
@Slf4j
@RestController
public class EmpCtrl {

    @Autowired
    private EmpServ service;
    @Autowired
    private SseEmitter sseEmitter;
    @Autowired
    private ExecutorService executorService;

    // URL - http://localhost:10093/emit-data-items
    @GetMapping("/emit-data-items")
    public SseEmitter fetchData() {
        log.info("Emitting the employee data sets.");
        executorService.execute(() -> {
            final List<Emp> employees = service.findAll();
            try {
                for (final Emp employee : employees) {
                    randomDelay();
                    sseEmitter.send(employee);
                }
                sseEmitter.complete();
            } catch (final IOException e) {
                log.info("IO exception occurred while emitting the employee data sets.");
                sseEmitter.completeWithError(e);
            }
        });
        executorService.shutdown();
        return sseEmitter;
    }

    // Private method to put a random delay in between the records.
    private void randomDelay() {
        try {
            Thread.sleep(1000);
        } catch (final InterruptedException e) {
            log.info("Thread is interrupted.");
            Thread.currentThread().interrupt();
        }
    }
}
